[SCM] WebKit Debian packaging branch, debian/unstable, updated. debian/1.1.15-1-40151-g37bb677

sullivan sullivan at 268f45cc-cd09-0410-ab3c-d52691b4dbfc
Sat Sep 26 08:48:52 UTC 2009


The following commit has been merged in the debian/unstable branch:
commit ae2b218bbcb035c99765838e1e35ebac305ab33e
Author: sullivan <sullivan at 268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Tue Jul 6 16:45:13 2004 +0000

            Reviewed by Trey.
    
            - fixed <rdar://problem/3717147> folder icon used for error page in back/forward
            menu when iTunes is not installed
    
            * WebView.subproj/WebFrame.m:
            (-[WebFrame _transitionToCommitted:]):
            When displaying the error page for an unreachable URL, leave the requested URL
            in the WebHistoryItem; don't clobber it with a bogus one that represents the
            error page. This not only avoids the wrong-icon problem, but should also help
            in cases where an unreachable URL becomes reachable later on.
    
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@6963 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKit/ChangeLog b/WebKit/ChangeLog
index 73a84bd..e8c3188 100644
--- a/WebKit/ChangeLog
+++ b/WebKit/ChangeLog
@@ -1,3 +1,17 @@
+2004-07-06  John Sullivan  <sullivan at apple.com>
+
+        Reviewed by Trey.
+
+        - fixed <rdar://problem/3717147> folder icon used for error page in back/forward 
+        menu when iTunes is not installed
+
+        * WebView.subproj/WebFrame.m:
+        (-[WebFrame _transitionToCommitted:]):
+        When displaying the error page for an unreachable URL, leave the requested URL
+        in the WebHistoryItem; don't clobber it with a bogus one that represents the
+        error page. This not only avoids the wrong-icon problem, but should also help
+        in cases where an unreachable URL becomes reachable later on.
+
 2004-07-06  Trey Matteson  <trey at apple.com>
 
 	3716053 - www.theage.com.au has extra back/forward items due to ads
@@ -42,6 +56,7 @@
         (-[WebHTMLView _startDraggingImage:at:operation:event:sourceIsDHTML:DHTMLWroteData:]):
 	Ask for slideback.
 
+>>>>>>> 1.2612
 2004-07-02  Darin Adler  <darin at apple.com>
 
         Reviewed by Dave.
diff --git a/WebKit/WebView.subproj/WebFrame.m b/WebKit/WebView.subproj/WebFrame.m
index dd10937..e4c07c1 100644
--- a/WebKit/WebView.subproj/WebFrame.m
+++ b/WebKit/WebView.subproj/WebFrame.m
@@ -744,11 +744,18 @@ NSString *WebPageCacheDocumentViewKey = @"WebPageCacheDocumentViewKey";
                     }
 
                 } else {
-                    // update the URL in the BF list that we made before the redirect
-                    [[_private currentItem] setURL:[[ds request] URL]];
-                    // clear out the form data so we don't repost it to the wrong place if we
-                    // ever go back/forward to this item
-                    [[_private currentItem] _setFormInfoFromRequest:[ds request]];
+                    NSURLRequest *request = [ds request];
+                    
+                    // update the URL in the BF list that we made before the redirect, unless
+                    // this is alternate content for an unreachable URL (we want the BF list
+                    // item to remember the unreachable URL in case it becomes reachable later)
+                    if ([request _webDataRequestUnreachableURL] == nil) {
+                        [[_private currentItem] setURL:[request URL]];
+
+                        // clear out the form data so we don't repost it to the wrong place if we
+                        // ever go back/forward to this item
+                        [[_private currentItem] _setFormInfoFromRequest:request];
+                    }
                 }
                 [self _makeDocumentView];
                 break;

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list